@@ -1,19 +1,21 @@
 package DateTime::TimeZone;
 
+use 5.006;
+
 use strict;
+use warnings;
 
-use vars qw( $VERSION );
-$VERSION = '0.6603';
+our $VERSION = '1.19';
 
-use DateTime::TimeZoneCatalog;
+use DateTime::TimeZone::Catalog;
 use DateTime::TimeZone::Floating;
 use DateTime::TimeZone::Local;
 use DateTime::TimeZone::OffsetOnly;
 use DateTime::TimeZone::UTC;
 use Params::Validate qw( validate validate_pos SCALAR ARRAYREF BOOLEAN );
 
-use constant INFINITY     =>       100 ** 1000 ;
-use constant NEG_INFINITY => -1 * (100 ** 1000);
+use constant INFINITY => 100**1000;
+use constant NEG_INFINITY => -1 * ( 100**1000 );
 
 # the offsets for each span element
 use constant UTC_START   => 0;
@@ -24,40 +26,34 @@ use constant OFFSET      => 4;
 use constant IS_DST      => 5;
 use constant SHORT_NAME  => 6;
 
-my %SpecialName = map { $_ => 1 } qw( EST MST HST EST5EDT CST6CDT MST7MDT PST8PDT );
+my %SpecialName = map { $_ => 1 }
+    qw( EST MST HST CET EET MET WET EST5EDT CST6CDT MST7MDT PST8PDT );
 
-sub new
-{
+sub new {
     my $class = shift;
-    my %p = validate( @_,
-                      { name => { type => SCALAR } },
-                    );
+    my %p     = validate(
+        @_,
+        { name => { type => SCALAR } },
+    );
 
-    if ( exists $DateTime::TimeZone::LINKS{ $p{name} } )
-    {
-        $p{name} = $DateTime::TimeZone::LINKS{ $p{name} };
+    if ( exists $DateTime::TimeZone::Catalog::LINKS{ $p{name} } ) {
+        $p{name} = $DateTime::TimeZone::Catalog::LINKS{ $p{name} };
     }
-    elsif ( exists $DateTime::TimeZone::LINKS{ uc $p{name} } )
-    {
-        $p{name} = $DateTime::TimeZone::LINKS{ uc $p{name} };
+    elsif ( exists $DateTime::TimeZone::Catalog::LINKS{ uc $p{name} } ) {
+        $p{name} = $DateTime::TimeZone::Catalog::LINKS{ uc $p{name} };
     }
 
     unless ( $p{name} =~ m,/,
-             || $SpecialName{ $p{name} }
-           )
-    {
-        if ( $p{name} eq 'floating' )
-        {
+        || $SpecialName{ $p{name} } ) {
+        if ( $p{name} eq 'floating' ) {
             return DateTime::TimeZone::Floating->new;
         }
 
-        if ( $p{name} eq 'local' )
-        {
+        if ( $p{name} eq 'local' ) {
             return DateTime::TimeZone::Local->TimeZone();
         }
 
-        if ( $p{name} eq 'UTC' || $p{name} eq 'Z' )
-        {
+        if ( $p{name} eq 'UTC' || $p{name} eq 'Z' ) {
             return DateTime::TimeZone::UTC->new;
         }
 
@@ -72,62 +68,63 @@ sub new
     die "The timezone '$p{name}' in an invalid name.\n"
         unless $real_class =~ /^\w+(::\w+)*$/;
 
-    unless ( $real_class->can('instance') )
-    {
-        eval "require $real_class";
+    unless ( $real_class->can('instance') ) {
+        my $e = do {
+            local $@;
+            local $SIG{__DIE__};
+            eval "require $real_class";
+            $@;
+        };
 
-        if ($@)
-        {
+        if ($e) {
             my $regex = join '.', split /::/, $real_class;
             $regex .= '\\.pm';
 
-            if ( $@ =~ /^Can't locate $regex/i )
-            {
-                die "The timezone '$p{name}' could not be loaded, or is an invalid name.\n";
+            if ( $e =~ /^Can't locate $regex/i ) {
+                die
+                    "The timezone '$p{name}' could not be loaded, or is an invalid name.\n";
             }
-            else
-            {
-                die $@;
+            else {
+                die $e;
             }
         }
     }
 
     my $zone = $real_class->instance( name => $p{name}, is_olson => 1 );
 
-    if ( $zone->is_olson() )
-    {
-        my $object_version =
-            $zone->can('olson_version')
+    if ( $zone->is_olson() ) {
+        my $object_version
+            = $zone->can('olson_version')
             ? $zone->olson_version()
             : 'unknown';
-        my $catalog_version = __PACKAGE__->catalog_olson_version();
+        my $catalog_version = DateTime::TimeZone::Catalog->OlsonVersion();
 
-        if ( $object_version ne $catalog_version )
-        {
-            warn "Loaded $real_class, which is from an older version ($object_version) of the Olson database than this installation of DateTime::TimeZone ($catalog_version).\n";
+        if ( $object_version ne $catalog_version ) {
+            warn
+                "Loaded $real_class, which is from an older version ($object_version) of the Olson database than this installation of DateTime::TimeZone ($catalog_version).\n";
         }
     }
 
     return $zone;
 }
 
-sub _init
-{
+sub _init {
     my $class = shift;
-    my %p = validate( @_,
-                      { name     => { type => SCALAR },
-                        spans    => { type => ARRAYREF },
-                        is_olson => { type => BOOLEAN, default => 0 },
-                      },
-                    );
+    my %p     = validate(
+        @_, {
+            name     => { type => SCALAR },
+            spans    => { type => ARRAYREF },
+            is_olson => { type => BOOLEAN, default => 0 },
+        },
+    );
 
-    my $self = bless { name     => $p{name},
-                       spans    => $p{spans},
-                       is_olson => $p{is_olson},
-                     }, $class;
+    my $self = bless {
+        name     => $p{name},
+        spans    => $p{spans},
+        is_olson => $p{is_olson},
+    }, $class;
 
-    foreach my $k ( qw( last_offset last_observance rules max_year ) )
-    {
+    foreach my $k (qw( last_offset last_observance rules max_year )) {
         my $m = "_$k";
         $self->{$k} = $self->$m() if $self->can($m);
     }
@@ -137,8 +134,7 @@ sub _init
 
 sub is_olson { $_[0]->{is_olson} }
 
-sub is_dst_for_datetime
-{
+sub is_dst_for_datetime {
     my $self = shift;
 
     my $span = $self->_span_for_datetime( 'utc', $_[0] );
@@ -146,8 +142,7 @@ sub is_dst_for_datetime
     return $span->[IS_DST];
 }
 
-sub offset_for_datetime
-{
+sub offset_for_datetime {
     my $self = shift;
 
     my $span = $self->_span_for_datetime( 'utc', $_[0] );
@@ -155,8 +150,7 @@ sub offset_for_datetime
     return $span->[OFFSET];
 }
 
-sub offset_for_local_datetime
-{
+sub offset_for_local_datetime {
     my $self = shift;
 
     my $span = $self->_span_for_datetime( 'local', $_[0] );
@@ -164,8 +158,7 @@ sub offset_for_local_datetime
     return $span->[OFFSET];
 }
 
-sub short_name_for_datetime
-{
+sub short_name_for_datetime {
     my $self = shift;
 
     my $span = $self->_span_for_datetime( 'utc', $_[0] );
@@ -173,8 +166,7 @@ sub short_name_for_datetime
     return $span->[SHORT_NAME];
 }
 
-sub _span_for_datetime
-{
+sub _span_for_datetime {
     my $self = shift;
     my $type = shift;
     my $dt   = shift;
@@ -185,20 +177,18 @@ sub _span_for_datetime
 
     my $span;
     my $seconds = $dt->$method();
-    if ( $seconds < $self->max_span->[$end] )
-    {
+    if ( $seconds < $self->max_span->[$end] ) {
         $span = $self->_spans_binary_search( $type, $seconds );
     }
-    else
-    {
+    else {
         my $until_year = $dt->utc_year + 1;
-        $span = $self->_generate_spans_until_match( $until_year, $seconds, $type );
+        $span = $self->_generate_spans_until_match( $until_year, $seconds,
+            $type );
     }
 
     # This means someone gave a local time that doesn't exist
     # (like during a transition into savings time)
-    unless ( defined $span )
-    {
+    unless ( defined $span ) {
         my $err = 'Invalid local time for date';
         $err .= ' ' . $dt->iso8601 if $type eq 'utc';
         $err .= " in time zone: " . $self->name;
@@ -210,8 +200,7 @@ sub _span_for_datetime
     return $span;
 }
 
-sub _spans_binary_search
-{
+sub _spans_binary_search {
     my $self = shift;
     my ( $type, $seconds ) = @_;
 
@@ -219,18 +208,17 @@ sub _spans_binary_search
 
     my $min = 0;
     my $max = scalar @{ $self->{spans} } + 1;
-    my $i = int( $max / 2 );
+    my $i   = int( $max / 2 );
+
     # special case for when there are only 2 spans
     $i++ if $max % 2 && $max != 3;
 
     $i = 0 if @{ $self->{spans} } == 1;
 
-    while (1)
-    {
+    while (1) {
         my $current = $self->{spans}[$i];
 
-        if ( $seconds < $current->[$start] )
-        {
+        if ( $seconds < $current->[$start] ) {
             $max = $i;
             my $c = int( ( $i - $min ) / 2 );
             $c ||= 1;
@@ -239,8 +227,7 @@ sub _spans_binary_search
 
             return if $i < $min;
         }
-        elsif ( $seconds >= $current->[$end] )
-        {
+        elsif ( $seconds >= $current->[$end] ) {
             $min = $i;
             my $c = int( ( $max - $i ) / 2 );
             $c ||= 1;
@@ -249,14 +236,19 @@ sub _spans_binary_search
 
             return if $i >= $max;
         }
-        else
-        {
+        else {
+
             # Special case for overlapping ranges because of DST and
             # other weirdness (like Alaska's change when bought from
             # Russia by the US).  Always prefer latest span.
-            if ( $current->[IS_DST] && $type eq 'local' )
-            {
-                my $next = $self->{spans}[$i + 1];
+            if ( $current->[IS_DST] && $type eq 'local' ) {
+
+                # Asia/Dhaka in 2009j goes into DST without any known
+                # end-of-DST date (wtf, Bangladesh).
+                return $current if $current->[UTC_END] == INFINITY;
+
+                my $next = $self->{spans}[ $i + 1 ];
+
                 # Sometimes we will get here and the span we're
                 # looking at is the last that's been generated so far.
                 # We need to try to generate one more or else we run
@@ -265,11 +257,9 @@ sub _spans_binary_search
 
                 die "No next span in $self->{max_year}" unless defined $next;
 
-                if ( ( ! $next->[IS_DST] )
-                     && $next->[$start] <= $seconds
-                     && $seconds        <= $next->[$end]
-                   )
-                {
+                if (   ( !$next->[IS_DST] )
+                    && $next->[$start] <= $seconds
+                    && $seconds <= $next->[$end] ) {
                     return $next;
                 }
             }
@@ -279,8 +269,7 @@ sub _spans_binary_search
     }
 }
 
-sub _generate_next_span
-{
+sub _generate_next_span {
     my $self = shift;
 
     my $last_idx = $#{ $self->{spans} };
@@ -292,83 +281,80 @@ sub _generate_next_span
     # by looking two years out we can ensure that we will find at
     # least one more span.  Of course, I will no doubt be proved wrong
     # and this will cause errors.
-    $self->_generate_spans_until_match
-        ( $self->{max_year} + 2, $max_span->[UTC_END] + ( 366 * 86400 ), 'utc' );
+    $self->_generate_spans_until_match( $self->{max_year} + 2,
+        $max_span->[UTC_END] + ( 366 * 86400 ), 'utc' );
 
     return $self->{spans}[ $last_idx + 1 ];
 }
 
-sub _generate_spans_until_match
-{
-    my $self = shift;
+sub _generate_spans_until_match {
+    my $self                = shift;
     my $generate_until_year = shift;
-    my $seconds = shift;
-    my $type = shift;
+    my $seconds             = shift;
+    my $type                = shift;
 
     my @changes;
     my @rules = @{ $self->_rules };
-    foreach my $year ( $self->{max_year} .. $generate_until_year )
-    {
-        for ( my $x = 0; $x < @rules; $x++ )
-        {
+    foreach my $year ( $self->{max_year} .. $generate_until_year ) {
+        for ( my $x = 0; $x < @rules; $x++ ) {
             my $last_offset_from_std;
 
-            if ( @rules == 2 )
-            {
-                $last_offset_from_std =
-                    $x ? $rules[0]->offset_from_std : $rules[1]->offset_from_std;
+            if ( @rules == 2 ) {
+                $last_offset_from_std
+                    = $x
+                    ? $rules[0]->offset_from_std
+                    : $rules[1]->offset_from_std;
             }
-            elsif ( @rules == 1 )
-            {
+            elsif ( @rules == 1 ) {
                 $last_offset_from_std = $rules[0]->offset_from_std;
             }
-            else
-            {
+            else {
                 my $count = scalar @rules;
-                die "Cannot generate future changes for zone with $count infinite rules\n";
+                die
+                    "Cannot generate future changes for zone with $count infinite rules\n";
             }
 
             my $rule = $rules[$x];
 
-            my $next =
-                $rule->utc_start_datetime_for_year
-                    ( $year, $self->{last_offset}, $last_offset_from_std );
+            my $next = $rule->utc_start_datetime_for_year( $year,
+                $self->{last_offset}, $last_offset_from_std );
 
             # don't bother with changes we've seen already
             next if $next->utc_rd_as_seconds < $self->max_span->[UTC_END];
 
             push @changes,
-                DateTime::TimeZone::OlsonDB::Change->new
-                    ( type => 'rule',
-                      utc_start_datetime   => $next,
-                      local_start_datetime =>
-                      $next +
-                      DateTime::Duration->new
-                          ( seconds => $self->{last_observance}->total_offset +
-                                       $rule->offset_from_std ),
-                      short_name =>
-                      sprintf( $self->{last_observance}->format, $rule->letter ),
-                      observance => $self->{last_observance},
-                      rule       => $rule,
-                    );
+                DateTime::TimeZone::OlsonDB::Change->new(
+                type                 => 'rule',
+                utc_start_datetime   => $next,
+                local_start_datetime => $next + DateTime::Duration->new(
+                    seconds => $self->{last_observance}->total_offset
+                        + $rule->offset_from_std
+                ),
+                short_name => sprintf(
+                    $self->{last_observance}->format, $rule->letter
+                ),
+                observance => $self->{last_observance},
+                rule       => $rule,
+                );
         }
     }
 
     $self->{max_year} = $generate_until_year;
 
-    my @sorted = sort { $a->utc_start_datetime <=> $b->utc_start_datetime } @changes;
+    my @sorted
+        = sort { $a->utc_start_datetime <=> $b->utc_start_datetime } @changes;
 
     my ( $start, $end ) = _keys_for_type($type);
 
     my $match;
-    for ( my $x = 1; $x < @sorted; $x++ )
-    {
-        my $last_total_offset =
-            $x == 1 ? $self->max_span->[OFFSET] : $sorted[ $x - 2 ]->total_offset;
+    for ( my $x = 1; $x < @sorted; $x++ ) {
+        my $last_total_offset
+            = $x == 1
+            ? $self->max_span->[OFFSET]
+            : $sorted[ $x - 2 ]->total_offset;
 
-        my $span =
-            DateTime::TimeZone::OlsonDB::Change::two_changes_as_span
-                ( @sorted[ $x - 1, $x ], $last_total_offset );
+        my $span = DateTime::TimeZone::OlsonDB::Change::two_changes_as_span(
+            @sorted[ $x - 1, $x ], $last_total_offset );
 
         $span = _span_as_array($span);
 
@@ -383,54 +369,56 @@ sub _generate_spans_until_match
 
 sub max_span { $_[0]->{spans}[-1] }
 
-sub _keys_for_type
-{
+sub _keys_for_type {
     $_[0] eq 'utc' ? ( UTC_START, UTC_END ) : ( LOCAL_START, LOCAL_END );
 }
 
-sub _span_as_array
-{
-    [ @{ $_[0] }{ qw( utc_start utc_end local_start local_end offset is_dst short_name ) } ];
+sub _span_as_array {
+    [
+        @{ $_[0] }{
+            qw( utc_start utc_end local_start local_end offset is_dst short_name )
+            }
+    ];
 }
 
-sub is_floating { 0 }
+sub is_floating {0}
 
-sub is_utc { 0 }
+sub is_utc {0}
 
-sub has_dst_changes { 0 }
+sub has_dst_changes {0}
 
-sub name      { $_[0]->{name} }
-sub category  { (split /\//, $_[0]->{name}, 2)[0] }
+sub name { $_[0]->{name} }
+sub category { ( split /\//, $_[0]->{name}, 2 )[0] }
 
-sub is_valid_name
-{
-    my $tz = eval { $_[0]->new( name => $_[1] ) };
+sub is_valid_name {
+    my $tz;
+    {
+        local $@;
+        local $SIG{__DIE__};
+        $tz = eval { $_[0]->new( name => $_[1] ) };
+    }
 
-    return $tz && UNIVERSAL::isa( $tz, 'DateTime::TimeZone') ? 1 : 0
+    return $tz && $tz->isa('DateTime::TimeZone') ? 1 : 0;
 }
 
-sub STORABLE_freeze
-{
+sub STORABLE_freeze {
     my $self = shift;
 
     return $self->name;
 }
 
-sub STORABLE_thaw
-{
-    my $self = shift;
-    my $cloning = shift;
+sub STORABLE_thaw {
+    my $self       = shift;
+    my $cloning    = shift;
     my $serialized = shift;
 
     my $class = ref $self || $self;
 
     my $obj;
-    if ( $class->isa(__PACKAGE__) )
-    {
+    if ( $class->isa(__PACKAGE__) ) {
         $obj = __PACKAGE__->new( name => $serialized );
     }
-    else
-    {
+    else {
         $obj = $class->new( name => $serialized );
     }
 
@@ -442,9 +430,13 @@ sub STORABLE_thaw
 #
 # Functions
 #
-sub offset_as_seconds
-{
-    shift if eval { $_[0]->isa('DateTime::TimeZone') };
+sub offset_as_seconds {
+    {
+        local $@;
+        local $SIG{__DIE__};
+        shift if eval { $_[0]->isa('DateTime::TimeZone') };
+    }
+
     my $offset = shift;
 
     return undef unless defined $offset;
@@ -452,34 +444,36 @@ sub offset_as_seconds
     return 0 if $offset eq '0';
 
     my ( $sign, $hours, $minutes, $seconds );
-    if ( $offset =~ /^([\+\-])?(\d\d?):(\d\d)(?::(\d\d))?$/ )
-    {
+    if ( $offset =~ /^([\+\-])?(\d\d?):(\d\d)(?::(\d\d))?$/ ) {
         ( $sign, $hours, $minutes, $seconds ) = ( $1, $2, $3, $4 );
     }
-    elsif ( $offset =~ /^([\+\-])?(\d\d)(\d\d)(\d\d)?$/ )
-    {
+    elsif ( $offset =~ /^([\+\-])?(\d\d)(\d\d)(\d\d)?$/ ) {
         ( $sign, $hours, $minutes, $seconds ) = ( $1, $2, $3, $4 );
     }
-    else
-    {
+    else {
         return undef;
     }
 
     $sign = '+' unless defined $sign;
-    return undef unless $hours >= 0 && $hours <= 99;
+    return undef unless $hours >= 0   && $hours <= 99;
     return undef unless $minutes >= 0 && $minutes <= 59;
-    return undef unless ! defined( $seconds ) || ( $seconds >= 0 && $seconds <= 59 );
+    return undef
+        unless !defined($seconds) || ( $seconds >= 0 && $seconds <= 59 );
 
-    my $total =  $hours * 3600 + $minutes * 60;
+    my $total = $hours * 3600 + $minutes * 60;
     $total += $seconds if $seconds;
     $total *= -1 if $sign eq '-';
 
     return $total;
 }
 
-sub offset_as_string
-{
-    shift if eval { $_[0]->isa('DateTime::TimeZone') };
+sub offset_as_string {
+    {
+        local $@;
+        local $SIG{__DIE__};
+        shift if eval { $_[0]->isa('DateTime::TimeZone') };
+    }
+
     my $offset = shift;
 
     return undef unless defined $offset;
@@ -493,65 +487,65 @@ sub offset_as_string
     $offset %= 3600;
     my $mins = int( $offset / 60 );
     $offset %= 60;
-    my $secs = int( $offset );
+    my $secs = int($offset);
 
-    return ( $secs ?
-             sprintf( '%s%02d%02d%02d', $sign, $hours, $mins, $secs ) :
-             sprintf( '%s%02d%02d', $sign, $hours, $mins )
-           );
+    return (
+        $secs
+        ? sprintf( '%s%02d%02d%02d', $sign, $hours, $mins, $secs )
+        : sprintf( '%s%02d%02d',     $sign, $hours, $mins )
+    );
 }
 
-# These methods all operate on data contained in the DateTime/TimeZoneCatalog.pm file.
+# These methods all operate on data contained in the DateTime/TimeZone/Catalog.pm file.
 
-sub all_names
-{
-    return wantarray ? @DateTime::TimeZone::ALL : [@DateTime::TimeZone::ALL];
+sub all_names {
+    return
+        wantarray
+        ? @DateTime::TimeZone::Catalog::ALL
+        : [@DateTime::TimeZone::Catalog::ALL];
 }
 
-sub categories
-{
+sub categories {
     return wantarray
-        ? @DateTime::TimeZone::CATEGORY_NAMES
-        : [@DateTime::TimeZone::CATEGORY_NAMES];
+        ? @DateTime::TimeZone::Catalog::CATEGORY_NAMES
+        : [@DateTime::TimeZone::Catalog::CATEGORY_NAMES];
 }
 
-sub links
-{
-    return
-        wantarray ? %DateTime::TimeZone::LINKS : {%DateTime::TimeZone::LINKS};
-}
-
-sub names_in_category
-{
-    shift if $_[0]->isa('DateTime::TimeZone');
-    return unless exists $DateTime::TimeZone::CATEGORIES{ $_[0] };
-
+sub links {
     return
         wantarray
-        ? @{ $DateTime::TimeZone::CATEGORIES{ $_[0] } }
-        : [ $DateTime::TimeZone::CATEGORIES{ $_[0] } ];
+        ? %DateTime::TimeZone::Catalog::LINKS
+        : {%DateTime::TimeZone::Catalog::LINKS};
 }
 
-sub countries
-{
+sub names_in_category {
+    shift if $_[0]->isa('DateTime::TimeZone');
+    return unless exists $DateTime::TimeZone::Catalog::CATEGORIES{ $_[0] };
+
+    return wantarray
+        ? @{ $DateTime::TimeZone::Catalog::CATEGORIES{ $_[0] } }
+        : [ $DateTime::TimeZone::Catalog::CATEGORIES{ $_[0] } ];
+}
+
+sub countries {
     wantarray
-        ? ( sort keys %DateTime::TimeZone::ZONES_BY_COUNTRY )
-        : [ sort keys %DateTime::TimeZone::ZONES_BY_COUNTRY ];
+        ? ( sort keys %DateTime::TimeZone::Catalog::ZONES_BY_COUNTRY )
+        : [ sort keys %DateTime::TimeZone::Catalog::ZONES_BY_COUNTRY ];
 }
 
-sub names_in_country
-{
+sub names_in_country {
     shift if $_[0]->isa('DateTime::TimeZone');
 
-    return unless exists $DateTime::TimeZone::ZONES_BY_COUNTRY{ lc $_[0] };
+    return
+        unless
+        exists $DateTime::TimeZone::Catalog::ZONES_BY_COUNTRY{ lc $_[0] };
 
     return
         wantarray
-        ? @{ $DateTime::TimeZone::ZONES_BY_COUNTRY{ lc $_[0] } }
-        : $DateTime::TimeZone::ZONES_BY_COUNTRY{ lc $_[0] };
+        ? @{ $DateTime::TimeZone::Catalog::ZONES_BY_COUNTRY{ lc $_[0] } }
+        : $DateTime::TimeZone::Catalog::ZONES_BY_COUNTRY{ lc $_[0] };
 }
 
-
 1;
 
 __END__
@@ -623,34 +617,21 @@ C<DateTime::TimeZone::OffsetOnly> object is returned.
 If the "name" parameter is "local", then the module attempts to
 determine the local time zone for the system.
 
-First it checks C<$ENV> for keys named "TZ", "SYS$TIMEZONE_RULE",
-"SYS$TIMEZONE_NAME", "UCX$TZ", or "TCPIP$TZC" (the last 4 are for
-VMS).  If this is defined, and it is not the string "local", then it
-is treated as any other valid name (including "floating"), and the
-constructor tries to create a time zone based on that name.
+The method for finding the local zone varies by operating system. See
+the appropriate module for details of how we check for the local time
+zone.
 
-Next, it checks for the existence of a symlink at F</etc/localtime>.
-It follows this link to the real file and figures out what the file's
-name is.  It then tries to turn this name into a valid time zone.  For
-example, if this file is linked to F</usr/share/zoneinfo/US/Central>,
-it will end up trying "US/Central", which will then be converted to
-"America/Chicago" internally.
+=over 4
 
-Some systems just copy the relevant file to F</etc/localtime> instead
-of making a symlink.  In this case, we look in F</usr/share/zoneinfo>
-for a file that has the same size and content as F</etc/localtime> to
-determine the local time zone.
+=item * L<DateTime::TimeZone::Local::Unix>
 
-Then it checks for a file called F</etc/timezone> or F</etc/TIMEZONE>.
-If one of these exists, it is read and it tries to create a time zone
-with the name contained in the file.
+=item * L<DateTime::TimeZone::Local::Win32>
 
-Finally, it checks for a file called F</etc/sysconfig/clock>.  If this
-file exists, it looks for a line inside the file matching
-C</^(?:TIME)?ZONE="([^"]+)"/>.  If this line exists, it tries the
-value as a time zone name.
+=item * L<DateTime::TimeZone::Local::VMS>
 
-If none of these methods work, it gives up and dies.
+=back
+
+If a local time zone is not found, then an exception will be thrown.
 
 =head2 $tz->offset_for_datetime( $dt )
 
@@ -756,7 +737,7 @@ use C<Locale::Country> to do so.
 
 =head2 DateTime::TimeZone->names_in_country( $country_code )
 
-Given a two-letter ISO3066 country code, this method returns a list of
+Given a two-letter ISO3166 country code, this method returns a list of
 time zones used in that country. The country code may be of any
 case. In scalar context, it returns an array reference, while in list
 context it returns an array.
@@ -793,12 +774,33 @@ your module with Storable.
 =head1 SUPPORT
 
 Support for this module is provided via the datetime@perl.org email
-list.  See http://lists.perl.org/ for more details.
+list. See http://datetime.perl.org/?MailingList for details.
 
 Please submit bugs to the CPAN RT system at
 http://rt.cpan.org/NoAuth/ReportBug.html?Queue=datetime%3A%3Atimezone
 or via email at bug-datetime-timezone@rt.cpan.org.
 
+=head1 DONATIONS
+
+If you'd like to thank me for the work I've done on this module,
+please consider making a "donation" to me via PayPal. I spend a lot of
+free time creating free software, and would appreciate any support
+you'd care to offer.
+
+Please note that B<I am not suggesting that you must do this> in order
+for me to continue working on this particular software. I will
+continue to do so, inasmuch as I have in the past, for as long as it
+interests me.
+
+Similarly, a donation made in this way will probably not make me work
+on this software much more, unless I get so many donations that I can
+consider working on free software full time, which seems unlikely at
+best.
+
+To donate, log into PayPal and send money to autarch@urth.org or use
+the button on this page:
+L<http://www.urth.org/~autarch/fs-donation.html>
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
@@ -811,7 +813,7 @@ datetime@perl.org list.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2007 David Rolsky.  All rights reserved.  This
+Copyright (c) 2003-2008 David Rolsky.  All rights reserved.  This
 program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
